==> torrent_search_mcp-1.2.0-py3-none-any.whl: torrent_search/fastapi_server.py <==
from json import loads
from typing import Literal

from fastapi import FastAPI, HTTPException, Path, Query

from .wrapper import Torrent, TorrentSearchApi

app = FastAPI(
    title="TorrentSearch FastAPI",
    description="FastAPI server for TorrentSearch API.",
)

api_client = TorrentSearchApi()


@app.get("/", summary="Health Check", tags=["General"], response_model=dict[str, str])
async def health_check() -> dict[str, str]:
    """
    Endpoint to check the health of the service.
    """
    return {"status": "ok"}


@app.post(
    "/torrents/search",
    summary="Search Torrents",
    tags=["Torrents"],
    response_model=list[Torrent],
)
async def search_torrents(
    query: str,
    sources: list[Literal["thepiratebay.org", "nyaa.si", "yggtorrent"]] | None = None,
    max_items: int = 10,
) -> list[Torrent]:
    """
    Search for torrents on sources [thepiratebay.org, nyaa.si, yggtorrent].
    Corresponds to `TorrentSearchApi.search_torrents()`.
    """
    torrents: list[Torrent] = await api_client.search_torrents(
        query=query,
        sources=sources,
        max_items=max_items,
    )
    return torrents


@app.get(
    "/torrents/{torrent_id}",
    summary="Get Torrent Details",
    tags=["Torrents"],
    response_model=Torrent,
)
async def get_torrent_details(
    torrent_id: str = Path(..., description="The ID of the torrent."),
    original_search_params: str = Query(
        "{}",
        description='Original search parameters (can be omitted if from YGG Torrent). Format: {"query": "your_query", "max_items": 10}',
    ),
) -> Torrent:
    """
    Get details about a specific torrent by id and original search parameters (can be omitted if from YGG Torrent).
    Corresponds to `TorrentSearchApi.get_torrent_details()`.
    """
    torrent: Torrent | None = await api_client.get_torrent_details(
        torrent_id,
        original_search_params=loads(original_search_params),
    )
    if not torrent:
        raise HTTPException(
            status_code=404, detail=f"Torrent with ID {torrent_id} not found."
        )
    return torrent


@app.get(
    "/torrents/{torrent_id}/magnet",
    summary="Get Magnet Link",
    tags=["Torrents"],
    response_model=str,
)
async def get_magnet_link(
    torrent_id: str = Path(..., description="The ID of the torrent."),
    original_search_params: str = Query(
        "{}",
        description='Original search parameters (can be omitted if from YGG Torrent). Format: {"query": "your_query", "max_items": 10}',
    ),
) -> str:
    """
    Get the magnet link for a specific torrent by id and original search parameters (can be omitted if from YGG Torrent).
    Corresponds to `TorrentSearchApi.get_magnet_link()`.
    """
    magnet_link: str | None = await api_client.get_magnet_link(
        torrent_id,
        original_search_params=loads(original_search_params),
    )
    if not magnet_link:
        raise HTTPException(
            status_code=404, detail="Magnet link not found or could not be generated."
        )
    return magnet_link

==> torrent_search_mcp-1.4.1-py3-none-any.whl: torrent_search/fastapi_server.py <==
from fastapi import FastAPI, HTTPException, Path

from .wrapper import Torrent, TorrentSearchApi

app = FastAPI(
    title="TorrentSearch FastAPI",
    description="FastAPI server for TorrentSearch API.",
)

api_client = TorrentSearchApi()


@app.get("/", summary="Health Check", tags=["General"], response_model=dict[str, str])
async def health_check() -> dict[str, str]:
    """
    Endpoint to check the health of the service.
    """
    return {"status": "ok"}


@app.post(
    "/torrents/search",
    summary="Search Torrents",
    tags=["Torrents"],
    response_model=list[Torrent],
)
async def search_torrents(
    query: str,
    max_items: int = 10,
) -> list[Torrent]:
    """
    Search for torrents on sources [thepiratebay.org, nyaa.si, yggtorrent].
    Corresponds to `TorrentSearchApi.search_torrents()`.
    """
    torrents: list[Torrent] = await api_client.search_torrents(query, max_items)
    return torrents


@app.get(
    "/torrents/{torrent_id}",
    summary="Get Torrent Details",
    tags=["Torrents"],
    response_model=Torrent,
)
async def get_torrent_details(
    torrent_id: str = Path(..., description="The ID of the torrent."),
) -> Torrent:
    """
    Get details about a specific torrent by id.
    Corresponds to `TorrentSearchApi.get_torrent_details()`.
    """
    torrent: Torrent | None = await api_client.get_torrent_details(torrent_id)
    if not torrent:
        raise HTTPException(
            status_code=404, detail=f"Torrent with ID {torrent_id} not found."
        )
    return torrent


@app.get(
    "/torrents/{torrent_id}/magnet",
    summary="Get Magnet Link",
    tags=["Torrents"],
    response_model=str,
)
async def get_magnet_link(
    torrent_id: str = Path(..., description="The ID of the torrent."),
) -> str:
    """
    Get the magnet link for a specific torrent by id.
    Corresponds to `TorrentSearchApi.get_magnet_link()`.
    """
    magnet_link: str | None = await api_client.get_magnet_link(torrent_id)
    if not magnet_link:
        raise HTTPException(
            status_code=404, detail="Magnet link not found or could not be generated."
        )
    return magnet_link
